==> 0.0.17.tar.gz: west-sound-hall/src/app/club/page.tsx <==

import { type Metadata } from 'next'
import Image from 'next/image'
import Link from 'next/link'
import dynamic from "next/dynamic";
import clsx from 'clsx'

import { Container } from '@/components/Container'
import { UserPlusIcon, GiftIcon, EnvelopeIcon, UserGroupIcon } from '@heroicons/react/24/solid'
import interiorEmptyImage from '@/images/photos/interior-empty.jpg'

function SocialLink({
  className,
  href,
  children,
  icon: Icon,
}: {
  className?: string
  href: string
  icon: React.ComponentType<{ className?: string }>
  children: React.ReactNode
}) {
  return (
    <li className={clsx(className, 'flex')}>
      <Link
        href={href}
        className="group flex text-sm font-medium text-zinc-800 transition hover:text-teal-500 dark:text-zinc-200 dark:hover:text-teal-500"
      >
        <Icon className="h-6 w-6 flex-none fill-zinc-500 transition group-hover:fill-teal-500" />
        <span className="ml-4">{children}</span>
      </Link>
    </li>
  )
}

export const metadata: Metadata = {
  title: 'West Sound Community Club',
  description:
    'The West Sound Community Club on Orcas Island.',
}


// TODO: Replace interiorEmptyImage with a photo from a potluck

export default function Club() {

  // Dynamic import since ClubPayment uses `document`
  const ClubPayment = dynamic(
    () => {
      return import("./payment");
    },
    { ssr: false }
  );

  return (
    <Container className="mt-16 sm:mt-32">
      <div className="grid grid-cols-1 gap-y-16 lg:grid-cols-2 lg:grid-rows-[auto_1fr] lg:gap-y-12">
        <div className="lg:pl-20">
          <div className="max-w-xs px-2.5 lg:max-w-none">
            <Image
              src={interiorEmptyImage}
              alt=""
              sizes="(min-width: 1024px) 32rem, 20rem"
              className="aspect-square rounded-2xl bg-zinc-100 object-cover dark:bg-zinc-800"
            />
          </div>
        </div>
        <div className="lg:order-first lg:row-span-2">
          <h1 className="text-4xl font-bold tracking-tight text-zinc-800 dark:text-zinc-100 sm:text-5xl">
            West Sound Community Club
          </h1>
          <div className="mt-6 space-y-7 text-base text-zinc-600 dark:text-zinc-400">
            <p>
              The West Sound Community Club is a group of neighbors and friends
              living in the West Sound area. Together we steward the West Sound
              Hall, and gather monthly for potlucks and other community events.
            </p>

            <p>
              Members of the West Sound community, past and present, have
              invested time, money, and talent in creating a true old-fashioned
              community center. For over one hundred years, the hall has
              provided continuity for the residents and guests of the West Sound
              community. The current residents continue the commitment to
              maintain this unique gathering place out of care and respect for
              past and future generations.
            </p>

            <p>
              The West Sound Community Club is a nonprofit, tax-exempt corporation
              under Section 501(c)3 of the Internal Revenue Code.
            </p>
          </div>
        </div>
        <div className="lg:pl-20">
          <ul role="list">
            <SocialLink href="/WSCC-Membership-Form.pdf" icon={UserPlusIcon}>
              Membership Form
            </SocialLink>
            <SocialLink href="#" icon={GiftIcon} className="mt-4">
              Donations (Coming soon)
            </SocialLink>
            <SocialLink
              href="mailto:contact@westsoundhall.org"
              icon={EnvelopeIcon}
              className="mt-8 border-t border-zinc-100 pt-8 dark:border-zinc-700/40"
            >
              contact@westsoundhall.org
            </SocialLink>
            <SocialLink href="/board-of-directors" icon={UserGroupIcon} className="mt-4">
              Board of Directors
            </SocialLink>
          </ul>
        </div>
        <div>
          <h2 className="text-2xl mb-4 font-semibold leading-6 text-gray-900">
            Join or Renew your Membership
          </h2>
          <ClubPayment />
        </div>
      </div>
    </Container>
  )
}

==> 0.0.24.tar.gz: west-sound-hall/src/app/club/page.tsx <==

import { type Metadata } from 'next'
import Image from 'next/image'
import Link from 'next/link'
import dynamic from "next/dynamic";
import clsx from 'clsx'

import { Container } from '@/components/Container'
import { UserPlusIcon, AtSymbolIcon, EnvelopeIcon, UserGroupIcon } from '@heroicons/react/24/solid'
import interiorEmptyImage from '@/images/photos/interior-empty.jpg'

function SocialLink({
  className,
  href,
  children,
  icon: Icon,
}: {
  className?: string
  href: string
  icon: React.ComponentType<{ className?: string }>
  children: React.ReactNode
}) {
  return (
    <li className={clsx(className, 'flex')}>
      <Link
        href={href}
        className="group flex text-sm font-medium text-zinc-800 transition hover:text-teal-500"
      >
        <Icon className="h-6 w-6 flex-none fill-zinc-500 transition group-hover:fill-teal-500" />
        <span className="ml-4">{children}</span>
      </Link>
    </li>
  )
}

export const metadata: Metadata = {
  title: 'West Sound Community Club',
  description:
    'The West Sound Community Club on Orcas Island.',
}


// TODO: Replace interiorEmptyImage with a photo from a potluck

export default function Club() {

  // Dynamic import since ClubPayment uses `document`
  const ClubPayment = dynamic(
    () => {
      return import("./payment");
    },
    { ssr: false }
  );

  return (
    <Container className="mt-16 sm:mt-32">
      <div className="grid grid-cols-1 gap-y-16 lg:grid-cols-2 lg:grid-rows-[auto_1fr] lg:gap-y-12">
        <div className="lg:pl-20">
          <div className="max-w-xs px-2.5 lg:max-w-none">
            <Image
              src={interiorEmptyImage}
              alt=""
              sizes="(min-width: 1024px) 32rem, 20rem"
              className="aspect-square rounded-2xl bg-zinc-100 object-cover"
            />
          </div>
        </div>
        <div className="lg:order-first lg:row-span-2">
          <h1 className="text-4xl font-bold tracking-tight text-zinc-800 sm:text-5xl">
            West Sound Community Club
          </h1>
          <div className="mt-6 space-y-7 text-base text-zinc-600">
            <p>
              The West Sound Community Club is a group of neighbors and friends
              living in the West Sound area. Together we steward the West Sound
              Hall, and gather monthly for potlucks and other community events.
            </p>

            <p>
              Members of the West Sound community, past and present, have
              invested time, money, and talent in creating a true old-fashioned
              community center. For over one hundred years, the hall has
              provided continuity for the residents and guests of the West Sound
              community. The current residents continue the commitment to
              maintain this unique gathering place out of care and respect for
              past and future generations.
            </p>

            <p>
              The West Sound Community Club is a nonprofit, tax-exempt corporation
              under Section 501(c)3 of the Internal Revenue Code.
            </p>
          </div>
        </div>
        <div className="lg:pl-20">
          <ul role="list">
            <SocialLink href="/WSCC-Membership-Form.pdf" icon={UserPlusIcon}>
              Membership Form
            </SocialLink>
            <SocialLink href="https://groups.orcashub.org/invites/YkP79vjDtz" icon={AtSymbolIcon} className="mt-4">
              Club Member Mailing List
            </SocialLink>
            <SocialLink href="https://groups.orcashub.org/invites/Lg87tP3G2V" icon={AtSymbolIcon} className="mt-4">
              West Sound Neighbor to Neighbor Mailing List
            </SocialLink>
            <SocialLink
              href="mailto:contact@westsoundhall.org"
              icon={EnvelopeIcon}
              className="mt-8 border-t border-zinc-100 pt-8"
            >
              contact@westsoundhall.org
            </SocialLink>
            <SocialLink href="/board-of-directors" icon={UserGroupIcon} className="mt-4">
              Board of Directors
            </SocialLink>
          </ul>
        </div>
        <div>
          <h2 className="text-2xl mb-4 font-semibold leading-6 text-gray-900">
            Join or Renew your Membership
          </h2>
          <ClubPayment />
        </div>
      </div>
    </Container>
  )
}
